<?php
session_start(); // Initialize session data
ob_start(); // Turn on output buffering
?>
<?php include "ewcfg6.php" ?>
<?php include "ewmysql6.php" ?>
<?php include "phpfn6.php" ?>
<?php include "pv_deltroninfo.php" ?>
<?php include "usuarioinfo.php" ?>
<?php include "userfn6.php" ?>
<?php
header("Expires: Mon, 26 Jul 1997 05:00:00 GMT"); // Date in the past
header("Last-Modified: " . gmdate("D, d M Y H:i:s") . " GMT"); // Always modified
header("Cache-Control: private, no-store, no-cache, must-revalidate"); // HTTP/1.1 
header("Cache-Control: post-check=0, pre-check=0", false);
header("Pragma: no-cache"); // HTTP/1.0
?>
<?php

// Define page object
$pv_deltron_delete = new cpv_deltron_delete();
$Page =& $pv_deltron_delete;

// Page init processing
$pv_deltron_delete->Page_Init();

// Page main processing
$pv_deltron_delete->Page_Main();
?>
<?php include "header.php" ?>
<script type="text/javascript">
<!--

// Create page object
var pv_deltron_delete = new ew_Page("pv_deltron_delete");

// page properties
pv_deltron_delete.PageID = "delete"; // page ID
var EW_PAGE_ID = pv_deltron_delete.PageID; // for backward compatibility

// extend page with Form_CustomValidate function
pv_deltron_delete.Form_CustomValidate = 
 function(fobj) { // DO NOT CHANGE THIS LINE!

 	// Your custom validation code here, return false if invalid. 
 	return true;
 }
<?php if (EW_CLIENT_VALIDATE) { ?>
pv_deltron_delete.ValidateRequired = true; // uses JavaScript validation
<?php } else { ?>
pv_deltron_delete.ValidateRequired = false; // no JavaScript validation
<?php } ?>

//-->
</script>
<script language="JavaScript" type="text/javascript">
<!--

// Write your client script here, no need to add script tags.
// To include another .js script, use:
// ew_ClientScriptInclude("my_javascript.js"); 
//-->

</script>
<?php

// Load records for display
$rs = $pv_deltron_delete->LoadRecordset();
$pv_deltron_deletelTotalRecs = $rs->RecordCount(); // Get record count
if ($pv_deltron_deletelTotalRecs <= 0) { // No record found, exit
	$rs->Close();
	$pv_deltron_delete->Page_Terminate("pv_deltronlist.php"); // Return to list
}
?>
<p><span class="phpmaker">Delete From TABLE: pv deltron<br><br>
<a href="<?php echo $pv_deltron->getReturnUrl() ?>">Go Back</a></span></p>
<?php $pv_deltron_delete->ShowMessage() ?>
<form action="<?php echo ew_CurrentPage() ?>" method="post">
<p>
<input type="hidden" name="t" id="t" value="pv_deltron">
<input type="hidden" name="a_delete" id="a_delete" value="D">
<?php foreach ($pv_deltron_delete->arRecKeys as $key) { ?>
<input type="hidden" name="key_m[]" id="key_m[]" value="<?php echo ew_HtmlEncode($key) ?>">
<?php } ?>
<table class="ewGrid"><tr><td class="ewGridContent">
<div class="ewGridMiddlePanel">
<table cellspacing="0" class="ewTable ewTableSeparate">
<?php echo $pv_deltron->TableCustomInnerHtml ?>
	<thead>
	<tr class="ewTableHeader">
		<td valign="top">categoria</td>
		<td valign="top">codigo</td>
		<td valign="top">nombre</td>
		<td valign="top">stock DT</td>
		<td valign="top">pr DT</td>
		<td valign="top">precio s</td>
		<td valign="top">garantia</td>
		<td valign="top">marca</td>
	</tr>
	</thead>
	<tbody>
<?php
$pv_deltron_delete->lRecCnt = 0;
$i = 0;
while (!$rs->EOF) {
	$pv_deltron_delete->lRecCnt++;

	// Set row properties
	$pv_deltron->CssClass = "";
	$pv_deltron->CssStyle = "";
	$pv_deltron->RowType = EW_ROWTYPE_VIEW; // View

	// Get the field contents
	$pv_deltron_delete->LoadRowValues($rs);

	// Render row
	$pv_deltron_delete->RenderRow();
?>
	<tr<?php echo $pv_deltron->RowAttributes() ?>>
		<td<?php echo $pv_deltron->categoria->CellAttributes() ?>>
<div<?php echo $pv_deltron->categoria->ViewAttributes() ?>><?php echo $pv_deltron->categoria->ListViewValue() ?></div></td>
		<td<?php echo $pv_deltron->codigo->CellAttributes() ?>>
<div<?php echo $pv_deltron->codigo->ViewAttributes() ?>><?php echo $pv_deltron->codigo->ListViewValue() ?></div></td>
		<td<?php echo $pv_deltron->nombre->CellAttributes() ?>>
<div<?php echo $pv_deltron->nombre->ViewAttributes() ?>><?php echo $pv_deltron->nombre->ListViewValue() ?></div></td>
		<td<?php echo $pv_deltron->stockDT->CellAttributes() ?>>
<div<?php echo $pv_deltron->stockDT->ViewAttributes() ?>><?php echo $pv_deltron->stockDT->ListViewValue() ?></div></td>
		<td<?php echo $pv_deltron->prDT->CellAttributes() ?>>
<div<?php echo $pv_deltron->prDT->ViewAttributes() ?>><?php echo $pv_deltron->prDT->ListViewValue() ?></div></td>
		<td<?php echo $pv_deltron->precio_s->CellAttributes() ?>>
<div<?php echo $pv_deltron->precio_s->ViewAttributes() ?>><?php echo $pv_deltron->precio_s->ListViewValue() ?></div></td>
		<td<?php echo $pv_deltron->garantia->CellAttributes() ?>>
<div<?php echo $pv_deltron->garantia->ViewAttributes() ?>><?php echo $pv_deltron->garantia->ListViewValue() ?></div></td>
		<td<?php echo $pv_deltron->marca->CellAttributes() ?>>
<div<?php echo $pv_deltron->marca->ViewAttributes() ?>><?php echo $pv_deltron->marca->ListViewValue() ?></div></td>
	</tr>
<?php
	$rs->MoveNext();
}
$rs->Close();
?>
</tbody>
</table>
</div>
</td></tr></table>
<p>
<input type="submit" name="Action" id="Action" value="Confirm Delete">
</form>
<script language="JavaScript" type="text/javascript">
<!--

// Write your table-specific startup script here
// document.write("page loaded");
//-->

</script>
<?php include "footer.php" ?>
<?php

//
// Page Class
//
class cpv_deltron_delete {

	// Page ID
	var $PageID = 'delete';

	// Table Name
	var $TableName = 'pv_deltron';

	// Page Object Name
	var $PageObjName = 'pv_deltron_delete';

	// Page Name
	function PageName() {
		return ew_CurrentPage();
	}

	// Page Url
	function PageUrl() {
		$PageUrl = ew_CurrentPage() . "?";
		global $pv_deltron;
		if ($pv_deltron->UseTokenInUrl) $PageUrl .= "t=" . $pv_deltron->TableVar . "&"; // add page token
		return $PageUrl;
	}

	// Message
	function getMessage() {
		return @$_SESSION[EW_SESSION_MESSAGE];
	}

	function setMessage($v) {
		if (@$_SESSION[EW_SESSION_MESSAGE] <> "") { // Append
			$_SESSION[EW_SESSION_MESSAGE] .= "<br>" . $v;
		} else {
			$_SESSION[EW_SESSION_MESSAGE] = $v;
		}
	}

	// Show Message
	function ShowMessage() {
		if ($this->getMessage() <> "") { // Message in Session, display
			echo "<p><span class=\"ewMessage\">" . $this->getMessage() . "</span></p>";
			$_SESSION[EW_SESSION_MESSAGE] = ""; // Clear message in Session
		}
	}

	// Validate Page request
	function IsPageRequest() {
		global $objForm, $pv_deltron;
		if ($pv_deltron->UseTokenInUrl) {

			//IsPageRequest = False
			if ($objForm)
				return ($pv_deltron->TableVar == $objForm->GetValue("t"));
			if (@$_GET["t"] <> "")
				return ($pv_deltron->TableVar == $_GET["t"]);
		} else {
			return TRUE;
		}
	}

	//
	//  Class initialize
	//  - init objects
	//  - open connection
	//
	function cpv_deltron_delete() {
		global $conn;

		// Initialize table object
		$GLOBALS["pv_deltron"] = new cpv_deltron();

		// Initialize other table object
		$GLOBALS['usuario'] = new cusuario();

		// Intialize page id (for backward compatibility)
		if (!defined("EW_PAGE_ID"))
			define("EW_PAGE_ID", 'delete', TRUE);

		// Initialize table name (for backward compatibility)
		if (!defined("EW_TABLE_NAME"))
			define("EW_TABLE_NAME", 'pv_deltron', TRUE);

		// Open connection to the database
		$conn = ew_Connect();
	}

	// 
	//  Page_Init
	//
	function Page_Init() {
		global $gsExport, $gsExportFile, $pv_deltron;
		global $Security;
		$Security = new cAdvancedSecurity();
		if (!$Security->IsLoggedIn()) $Security->AutoLogin();
		if (!$Security->IsLoggedIn()) {
			$Security->SaveLastUrl();
			$this->Page_Terminate("login.php");
		}

		// Global page loading event (in userfn6.php)
		Page_Loading();

		// Page load event, used in current page
		$this->Page_Load();
	}

	//
	//  Page_Terminate
	//  - called when exit page
	//  - if URL specified, redirect to the URL
	//
	function Page_Terminate($url = "") {
		global $conn;

		// Page unload event, used in current page
		$this->Page_Unload();

		// Global page unloaded event (in userfn*.php)
		Page_Unloaded();

		 // Close Connection
		$conn->Close();

		// Go to URL if specified
		if ($url <> "") {
			ob_end_clean();
			header("Location: $url");
		}
		exit();
	}
	var $lTotalRecs;
	var $lRecCnt;
	var $arRecKeys = array();

	// Page main processing
	function Page_Main() {
		global $pv_deltron;

		// Load Key Parameters
		$sKey = "";
		$bSingleDelete = TRUE; // Initialize as single delete
		$nKeySelected = 0; // Initialize selected key count
		$sFilter = "";
		if (@$_GET["codigo"] <> "") {
			$pv_deltron->codigo->setQueryStringValue($_GET["codigo"]);
			$sKey .= $pv_deltron->codigo->QueryStringValue;
		} else {
			$bSingleDelete = FALSE;
		}
		if ($bSingleDelete) {
			$nKeySelected = 1; // Set up key selected count
			$this->arRecKeys[0] = $sKey;
		} else {
			if (isset($_POST["key_m"])) { // Key in form
				$nKeySelected = count($_POST["key_m"]); // Set up key selected count
				$this->arRecKeys = ew_StripSlashes($_POST["key_m"]);
			}
		}
		if ($nKeySelected <= 0)
			$this->Page_Terminate("pv_deltronlist.php"); // No key specified, return to list

		// Build filter
		foreach ($this->arRecKeys as $sKey) {
			$sFilter .= "(";

			// Set up key field
			$sKeyFld = $sKey;
			$sFilter .= "`codigo`='" . ew_AdjustSql($sKeyFld) . "' AND ";
			if (substr($sFilter, -5) == " AND ") $sFilter = substr($sFilter, 0, strlen($sFilter)-5) . ") OR ";
		}
		if (substr($sFilter, -4) == " OR ") $sFilter = substr($sFilter, 0, strlen($sFilter)-4);

		// Set up filter (SQL WhHERE clause) and get return SQL
		// SQL constructor in SQL constructor in pv_deltron class, pv_deltroninfo.php

		$pv_deltron->CurrentFilter = $sFilter;

		// Get action
		if (@$_POST["a_delete"] <> "") {
			$pv_deltron->CurrentAction = $_POST["a_delete"];
		} else {
			$pv_deltron->CurrentAction = "I"; // Display record
		}
		switch ($pv_deltron->CurrentAction) {
			case "D": // Delete
				$pv_deltron->SendEmail = TRUE; // Send email on delete success
				if ($this->DeleteRows()) { // delete rows
					$this->setMessage("Delete succeeded"); // Set up success message
					$this->Page_Terminate($pv_deltron->getReturnUrl()); // Return to caller
				}
		}
	}

	//
	//  Function DeleteRows
	//  - Delete Records based on current filter
	//
	function DeleteRows() {
		global $conn, $Security, $pv_deltron;
		$DeleteRows = TRUE;
		$sWrkFilter = $pv_deltron->CurrentFilter;

		// Set up filter (Sql Where Clause) and get Return SQL
		// SQL constructor in pv_deltron class, pv_deltroninfo.php

		$pv_deltron->CurrentFilter = $sWrkFilter;
		$sSql = $pv_deltron->SQL();
		$conn->raiseErrorFn = 'ew_ErrorFn';
		$rs = $conn->Execute($sSql);
		$conn->raiseErrorFn = '';
		if ($rs === FALSE) {
			return FALSE;
		} elseif ($rs->EOF) {
			$this->setMessage("No records found"); // No record found
			$rs->Close();
			return FALSE;
		}
		$conn->BeginTrans();

		// Clone old rows
		$rsold = ($rs) ? $rs->GetRows() : array();
		if ($rs) $rs->Close();

		// Call row deleting event
		if ($DeleteRows) {
			foreach ($rsold as $row) {
				$DeleteRows = $pv_deltron->Row_Deleting($row);
				if (!$DeleteRows) break;
			}
		}
		if ($DeleteRows) {
			$sKey = "";
			foreach ($rsold as $row) {
				$sThisKey = "";
				if ($sThisKey <> "") $sThisKey .= EW_COMPOSITE_KEY_SEPARATOR;
				$sThisKey .= $row['codigo'];
				$conn->raiseErrorFn = 'ew_ErrorFn';
				$DeleteRows = $conn->Execute($pv_deltron->DeleteSQL($row)); // Delete
				$conn->raiseErrorFn = '';
				if ($DeleteRows === FALSE)
					break;
				if ($sKey <> "") $sKey .= ", ";
				$sKey .= $sThisKey;
			}
		} else {

			// Set up error message
			if ($pv_deltron->CancelMessage <> "") {
				$this->setMessage($pv_deltron->CancelMessage);
				$pv_deltron->CancelMessage = "";
			} else {
				$this->setMessage("Delete cancelled");
			}
		}
		if ($DeleteRows) {
			$conn->CommitTrans(); // Commit the changes
		} else {
			$conn->RollbackTrans(); // Rollback changes
		}

		// Call recordset deleted event
		if ($DeleteRows) {
			foreach ($rsold as $row) {
				$pv_deltron->Row_Deleted($row);
			}	
		}
		return $DeleteRows;
	}

	// Load recordset
	function LoadRecordset($offset = -1, $rowcnt = -1) {
		global $conn, $pv_deltron;

		// Call Recordset Selecting event
		$pv_deltron->Recordset_Selecting($pv_deltron->CurrentFilter);

		// Load list page SQL
		$sSql = $pv_deltron->SelectSQL();
		if ($offset > -1 && $rowcnt > -1) $sSql .= " LIMIT $offset, $rowcnt";

		// Load recordset
		$conn->raiseErrorFn = 'ew_ErrorFn';	
		$rs = $conn->Execute($sSql);
		$conn->raiseErrorFn = '';

		// Call Recordset Selected event
		$pv_deltron->Recordset_Selected($rs);
		return $rs;
	}

	// Load row based on key values
	function LoadRow() {
		global $conn, $Security, $pv_deltron;
		$sFilter = $pv_deltron->KeyFilter();

		// Call Row Selecting event
		$pv_deltron->Row_Selecting($sFilter);

		// Load sql based on filter
		$pv_deltron->CurrentFilter = $sFilter;
		$sSql = $pv_deltron->SQL();
		if ($rs = $conn->Execute($sSql)) {
			if ($rs->EOF) {
				$LoadRow = FALSE;
			} else {
				$LoadRow = TRUE;
				$rs->MoveFirst();
				$this->LoadRowValues($rs); // Load row values

				// Call Row Selected event
				$pv_deltron->Row_Selected($rs);
			}
			$rs->Close();
		} else {
			$LoadRow = FALSE;
		}
		return $LoadRow;
	}

	// Load row values from recordset
	function LoadRowValues(&$rs) {
		global $pv_deltron;
		$pv_deltron->categoria->setDbValue($rs->fields('categoria'));
		$pv_deltron->codigo->setDbValue($rs->fields('codigo'));
		$pv_deltron->nombre->setDbValue($rs->fields('nombre'));
		$pv_deltron->stockDT->setDbValue($rs->fields('stockDT'));
		$pv_deltron->prDT->setDbValue($rs->fields('prDT'));
		$pv_deltron->precio_s->setDbValue($rs->fields('precio_s'));
		$pv_deltron->garantia->setDbValue($rs->fields('garantia'));
		$pv_deltron->marca->setDbValue($rs->fields('marca'));
	}

	// Render row values based on field settings
	function RenderRow() {
		global $conn, $Security, $pv_deltron;

		// Call Row_Rendering event
		$pv_deltron->Row_Rendering();

		// Common render codes for all row types
		// categoria

		$pv_deltron->categoria->CellCssStyle = "";
		$pv_deltron->categoria->CellCssClass = "";

		// codigo
		$pv_deltron->codigo->CellCssStyle = "";
		$pv_deltron->codigo->CellCssClass = "";

		// nombre
		$pv_deltron->nombre->CellCssStyle = "";
		$pv_deltron->nombre->CellCssClass = "";

		// stockDT
		$pv_deltron->stockDT->CellCssStyle = "";
		$pv_deltron->stockDT->CellCssClass = "";

		// prDT
		$pv_deltron->prDT->CellCssStyle = "";
		$pv_deltron->prDT->CellCssClass = "";

		// precio_s
		$pv_deltron->precio_s->CellCssStyle = "";
		$pv_deltron->precio_s->CellCssClass = "";

		// garantia
		$pv_deltron->garantia->CellCssStyle = "";
		$pv_deltron->garantia->CellCssClass = "";

		// marca
		$pv_deltron->marca->CellCssStyle = "";
		$pv_deltron->marca->CellCssClass = "";
		if ($pv_deltron->RowType == EW_ROWTYPE_VIEW) { // View row

			// categoria
			$pv_deltron->categoria->ViewValue = $pv_deltron->categoria->CurrentValue;
			$pv_deltron->categoria->CssStyle = "";
			$pv_deltron->categoria->CssClass = "";
			$pv_deltron->categoria->ViewCustomAttributes = "";

			// codigo
			$pv_deltron->codigo->ViewValue = $pv_deltron->codigo->CurrentValue;
			$pv_deltron->codigo->CssStyle = "";
			$pv_deltron->codigo->CssClass = "";
			$pv_deltron->codigo->ViewCustomAttributes = "";

			// nombre
			$pv_deltron->nombre->ViewValue = $pv_deltron->nombre->CurrentValue;
			$pv_deltron->nombre->CssStyle = "";
			$pv_deltron->nombre->CssClass = "";
			$pv_deltron->nombre->ViewCustomAttributes = "";

			// stockDT
			$pv_deltron->stockDT->ViewValue = $pv_deltron->stockDT->CurrentValue;
			$pv_deltron->stockDT->CssStyle = "";
			$pv_deltron->stockDT->CssClass = "";
			$pv_deltron->stockDT->ViewCustomAttributes = "";

			// prDT
			$pv_deltron->prDT->ViewValue = $pv_deltron->prDT->CurrentValue;
			$pv_deltron->prDT->CssStyle = "";
			$pv_deltron->prDT->CssClass = "";
			$pv_deltron->prDT->ViewCustomAttributes = "";

			// precio_s
			$pv_deltron->precio_s->ViewValue = $pv_deltron->precio_s->CurrentValue;
			$pv_deltron->precio_s->CssStyle = "";
			$pv_deltron->precio_s->CssClass = "";
			$pv_deltron->precio_s->ViewCustomAttributes = "";

			// garantia
			$pv_deltron->garantia->ViewValue = $pv_deltron->garantia->CurrentValue;
			$pv_deltron->garantia->CssStyle = "";
			$pv_deltron->garantia->CssClass = "";
			$pv_deltron->garantia->ViewCustomAttributes = "";

			// marca
			$pv_deltron->marca->ViewValue = $pv_deltron->marca->CurrentValue;
			$pv_deltron->marca->CssStyle = "";
			$pv_deltron->marca->CssClass = "";
			$pv_deltron->marca->ViewCustomAttributes = "";

			// categoria
			$pv_deltron->categoria->HrefValue = "";

			// codigo
			$pv_deltron->codigo->HrefValue = "";

			// nombre
			$pv_deltron->nombre->HrefValue = "";

			// stockDT
			$pv_deltron->stockDT->HrefValue = "";

			// prDT
			$pv_deltron->prDT->HrefValue = "";

			// precio_s
			$pv_deltron->precio_s->HrefValue = "";

			// garantia
			$pv_deltron->garantia->HrefValue = "";

			// marca
			$pv_deltron->marca->HrefValue = "";
		}

		// Call Row Rendered event
		$pv_deltron->Row_Rendered();
	}

	// Page Load event
	function Page_Load() {

		//echo "Page Load";
	}

	// Page Unload event
	function Page_Unload() {

		//echo "Page Unload";
	}
}
?>
